==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-CO/general.php <==
<?php

    return [
    'accessories'			=> 'Accesorios',
    'activated'			    => 'Activado',
    'accessory'				=> 'Accesorio',
    'accessory_report'		=> 'Reporte de Accesorios',
    'action'                => 'Acción',
    'activity_report'		=> 'Reporte de Actividad',
    'address'				=> 'Dirección',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrador',
    'add_seats'             => 'Sitios añadidos',
    'all_assets'			=> 'Todos los activos',
    'all'       			=> 'Todo',
    'archived'              => 'Archivado',
    'asset_models'			=> 'Modelos de activos',
    'asset_model'			=> 'Modelo',
    'asset'					=> 'Activo',
    'asset_report'          => 'Reporte de Activos',
    'asset_tag'				=> 'Etiqueta de activo',
    'assets_available'		=> 'activos disponibles',
    'audit'				    => 'Auditoría',
    'audit_report'			=> 'Registro de auditoría',
    'assets'				=> 'Activos',
    'avatar_delete'         => 'Eliminar Avatar',
    'avatar_upload'         => 'Subir Avatar',
    'back'      			=> 'Atrás',
    'bad_data'      		=> 'No se ha encontrado nada. ¿Tal vez datos erróneos?',
    'bulkaudit'             => 'Auditoría masiva',
    'bulkaudit_status'      => 'Estado de auditoría',
    'bulk_checkout'  		=> 'Procesar en Lote',
    'bystatus'              => 'por Estado',
    'cancel'  				=> 'Cancelar',
    'categories'			=> 'Categorías',
    'category'				=> 'Categoría',
    'change' 		        => 'Entrada/Salida',
    'changeemail'  			=> 'Cambiar dirección de email',
    'changepassword'  		=> 'Cambiar contraseña',
    'checkin'  				=> 'Entrada',
    'checkin_from'  		=> 'Devolución de',
    'checkout'  			=> 'Asignar',
    'checkouts_count'       => 'Dar de Baja',
    'checkins_count'        => 'Dar de Alta',
    'user_requests_count'   => 'Solicitudes',
    'city'  				=> 'Ciudad',
	'click_here'			=> 'Haz clic aquí',
    'clear_selection'		=> 'Borrar selección',
    'companies'			    => 'Compañías',
    'company'				=> 'Empresa',
    'component'			    => 'Componente',
    'components'			=> 'Componentes',
	'complete'				=> 'Completo',
    'consumable'			=> 'Consumible',
    'consumables'			=> 'Consumibles',
    'country'  				=> 'Pais',
    'create'				=> 'Crear Localización',
    'created'               => 'Artículo creado',
    'created_asset'			=> 'equipo creado',
    'created_at' 			=> 'Creado el',
    'record_created' 		=> 'Registro Creado',
    'updated_at' 			=> 'Actualizado en',
    'currency'  			=> '€', // this is deprecated
    'current'  				=> 'Actual',
    'custom_report'         => 'Reporte de Equipos Personalizado',
    'dashboard'				=> 'Tablero',
    'days'      			=> 'días',
    'days_to_next_audit'    => 'Días a la próxima auditoría',
    'date'					=> 'Fecha Compra',
    'debug_warning'         => '¡Advertencia!',
    'debug_warning_text'    => 'Esta aplicación esta corriendo en modo producción con debugging activado. Esto puede exponer datos sensibles si su aplicación es accesible desde el exterior. Desactive el modo debug cambiando el valor <code>APP_DEBUG</code> en su archivo <code>.env</code> a <code>false</code>.',
    'delete'  				=> 'Borrar',
    'delete_confirm'  		=> '¿Estás seguro de eliminar :item?',
    'deleted'  				=> 'Borrado',
    'delete_seats'  		=> 'Asientos eliminados',
    'departments'           => 'Departamentos',
    'department'           => 'Departamento',
    'deployed'				=> 'Instalados - ',
    'depreciation_report'	=> 'Informe de amortización',
    'details'               => 'Detalles',
    'download'				=> 'Descargar',
    'download_all'				=> 'Descargar todo',
    'depreciation'			=> 'Amortización',
    'editprofile'  			=> 'Editar Perfil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Dominio de correo electrónico',
    'email_format'			=> 'Formato de correo electrónico',
    'email_domain_help'		=> 'Esto se utiliza para generar direcciones de correo electrónico cuando se importan',
    'filastname_format'			=> 'Primera Inicial del Apellido (jsmith@ejemplo.com)',
    'firstname_lastname_format'	=> 'Primer Nombre y Apellido (jane.smith@ejemplo.com)',
    'firstname_lastname_underscore_format' => 'Primer Nombre y Apellido (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Apellido First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'first'					=> 'Primero',
    'firstnamelastname'     => 'Nombre Apellido (jane.smith@ejemplo.com)',
    'lastname_firstinitial' => 'Apellido Inicial (smith_j@ejemplo.com)',
    'firstinitial.lastname' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Nombre',
    'first_name_format'		=> 'Primer Nombre (jane@ejemplo.com)',
    'files'                 => 'Archivos',
    'file_name'				=> 'Archivo',
    'file_type'             => 'Tipo de archivo',
    'file_uploads'			=> 'Carga de Archivos',
    'generate'				=> 'Generar',
     'github_markdown'      => 'Este campo acepta el <a href="https://help.github.com/articles/github-flavored-markdown/">formateo flavored de GitHub</a>.',
    'groups'				=> 'Grupos',
    'gravatar_email'        => 'Gravatar Email',
    'history'  			    => 'Historial',
    'history_for'  			=> 'Historial de',
    'id'  					=> 'Id',
    'image'                 => 'Imagen',
    'image_delete'         	=> 'Borrar imagen',
    'image_upload'         	=> 'Enviar imagen',
    'image_filetypes_help'  => 'Los tipos de archivo aceptados son jpg, webp, png, gif y svg. El tamaño máximo permitido es :size.',
    'import'         	    => 'Importar',
    'importing'         	=> 'Importando',
    'importing_help'        => 'Puedes importar activos, accesorios, licencias, componentes, insumos y usuarios vía archivos CSV.<br> <br> El CSV debe estar delimitado por comas y formateado con encabezados que coincidan con aquellos definidos en los <a href="https://snipe-it.readme.io/docs/importing" target="_new"> CSVs de muestra en la documentación</a>.',
    'import-history'        => 'Historial de Importación',
    'asset_maintenance'        => 'Mantenimiento de Equipo',
    'asset_maintenance_report' => 'Reporte de Mantenimiento de Equipo',
    'asset_maintenances'       => 'Mantenimientos de Equipo',
    'item'  				=> 'Item',
    'insufficient_permissions' => '¡Permisos insuficientes!',
    'kits'       			=> 'Equipamiento predefinido',
    'language'				=> 'Lenguaje',
    'last'					=> 'Último',
    'last_login'            => 'Último acceso',
    'last_name'             => 'Apellidos',
    'license'				=> 'Licencia',
    'license_report'        => 'Reporte de Licencias',
    'licenses_available'	=> 'licencias libres',
    'licenses'				=> 'Licencias',
    'list_all'				=> 'Listar Todo',
    'loading'				=> 'Cargando',
    'lock_passwords'        => 'El valor de este campo no será guardado en una instalación de demostración.',
    'feature_disabled'      => 'Esta característica se ha desactivado para la versión de demostración.',
    'location'              => 'Localización',
    'locations'				=> 'Localizaciones',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Desconexión',
    'lookup_by_tag'     => 'Buscar por etiqueta de activo',
    'maintenances'          => 'Mantenimientos',
    'manufacturer'			=> 'Fabricante',
    'manufacturers'			=> 'Fabricantes',
    'markdown'				=> 'Este campo permite <a href="https://help.github.com/articles/github-flavored-markdown/">Github con sabor a markdown</a>.',
    'min_amt'				=> 'Cantidad mínima',
    'min_amt_help'	=> 'Número mínimo de elementos que deben estar disponibles antes de obtiene desencadenar una alerta.',
    'model_no'				=> 'Modelo No.',
    'months'				=> 'Meses',
    'moreinfo'				=> 'Más Info',
    'name'					=> 'Nombre Localización',
    'next'					=> 'Siguiente',
    'next_audit_date'		=> 'Próxima fecha de auditoría',
    'last_audit'		    => 'Última auditoría',
    'new'					=> 'nuevo!',
    'no_depreciation'		=> 'No Amortizar',
    'no_results'			=> 'Sin Resultados.',
    'no'  					=> 'No',
    'notes'  				=> 'Notas',
    'order_number'          => 'Nùmero de orden',
    'page_menu'				=> 'Mostrando elementos de _MENU_',
    'pagination_info'		=> 'Mostrando _START_ de _END_ de elementos _TOTAL_',
    'pending'				=> 'Equipo Pendiente',
    'people'				=> 'Usuarios',
    'per_page'				=> 'Resultados Por Pag',
    'previous'				=> 'Previo',
    'processing'			=> 'Procesando',
    'profile'				=> 'Perfil',
    'purchase_cost'                              => 'Precio Compra',
    'purchase_date'         => 'Fecha de compra',
    'qty'		            => 'Cant',
    'quantity'		        => 'Cantidad',
    'ready_to_deploy'		=> 'Disponibles',
    'recent_activity'		=> 'Actividad Reciente',
    'remove_company'        => 'Eliminar Asociación de compañía',
    'reports'				=> 'Informes',
    'restored'				=> 'restaurado',
    'requested'				=> 'Solicitado',
    'request_canceled'      => 'Solicitud Cancelada',
    'save'  				=> 'Guardar',
    'select'				=> 'Seleccionar',
    'search'				=> 'Buscar',
    'select_category'       => 'Seleccione una categoría',
    'select_department'       => 'Seleccione un departamento',
    'select_depreciation'	=> 'Seleccionar un tipo de Amortización',
    'select_location'		=> 'Seleccionar una Ubicación',
    'select_manufacturer'	=> 'Seleccionar un Fabricante',
    'select_model'			=> 'Seleccionar un Modelo',
    'select_supplier'		=> 'Seleccionar un Proveedor',
    'select_user'			=> 'Seleccionar un usuario',
    'select_date'			=> 'Seleccione Fecha (AAAA-MM-DD)',
    'select_statuslabel'	=> 'Seleccionar Estado',
    'select_company'    	=> 'Seleccionar empresa',
    'select_asset'    		=> 'Seleccionar activos',
    'settings'				=> 'Opciones',
    'show_deleted'  		=> 'Mostrar Eliminado',
    'show_current'  		=> 'Mostrar actual',
    'sign_in'				=> 'Entrar',
    'signature'             => 'Firma',
    'skin'       			=> 'Tema',
    'slack_test_msg'        => '¡Parece que tu integración de Slack con Snipe-IT está funcionando!',
    'some_features_disabled' => 'MODO DE DEMOSTRACIÓN: Algunas funciones estan desactivadas para esta instalación.',
    'site_name'				=> 'Sitio',
    'state'  				=> 'Provincia',
    'status_labels'			=> 'Etiquetas Estados',
    'status'    			=> 'Estados',
    'supplier'              => 'Proveedor',
    'suppliers'  			=> 'Proveedores',
    'sure_to_delete'    => '¿Está seguro que desea eliminar',
    'submit'				=> 'Enviar',
    'target'                => 'Objetivo',
    'time_and_date_display' => 'Hora y fecha',
    'total_assets'			=> 'Equipos',
    'total_licenses'		=> 'licencias totales',
    'total_accessories'		=> 'total de accesorios',
    'total_consumables'		=> 'total de consumibles',
    'type'  				=> 'Tipo',
    'undeployable'			=> 'No Instalable',
    'unknown_admin'			=> 'Admin Desconocido',
    'username_format'		=> 'Formato del nombre de usuario',
    'update'                => 'Actualizar',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Subido',
    'user'					=> 'Usuario',
    'accepted'			    => 'aceptado',
    'declined'			    => 'declinado',
    'unaccepted_asset_report' => 'Activos no aceptados',
    'users'                 => 'Usuarios',
    'viewall'				=> 'Ver todos',
    'viewassets'  			=> 'Ver Equipos Asignados',
    'website'               => 'Sitio web',
    'welcome'				=> 'Bienvenido, :name',
    'years'					=> 'años',
    'yes' 					=> 'Si',
    'zip'  					=> 'Códio Postal',
    'noimage'				=> 'Imagen no subida o imagen no encontrada.',
    'token_expired'         => 'Su sesión ha expirado, Intente otra ves.',
    'login_enabled'         => 'Inicio de sesión habilitado',
    'audit_due'             => 'Auditoría pendiente',
    'audit_overdue'         => 'Auditoría retrasada',
    'accept'                => 'Aceptar :asset',
    'i_accept'              => 'Acepto',
    'i_decline'             => 'Rechazo',
    'sign_tos'              => 'Firma abajo para indicar que estás de acuerdo con los términos de servicio:',
    'clear_signature'       => 'Borrar firma',
    'show_help'             => 'Mostrar ayuda',
    'hide_help'             => 'Ocultar ayuda',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-CO/general.php <==
<?php

    return [
    'accessories'			=> 'Accesorios',
    'activated'			    => 'Activado',
    'accessory'				=> 'Accesorio',
    'accessory_report'		=> 'Reporte de Accesorios',
    'action'                => 'Acción',
    'activity_report'		=> 'Reporte de Actividad',
    'address'				=> 'Dirección',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrador',
    'add_seats'             => 'Sitios añadidos',
    'all_assets'			=> 'Todos los activos',
    'all'       			=> 'Todo',
    'archived'              => 'Archivado',
    'asset_models'			=> 'Modelos de activos',
    'asset_model'			=> 'Modelo',
    'asset'					=> 'Activo',
    'asset_report'          => 'Reporte de Activos',
    'asset_tag'				=> 'Etiqueta de activo',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Equipos disponibles',
    'accept_assets'         => 'Activos Aceptados :name',
    'accept_assets_menu'    => 'Activos Aceptados',
    'audit'				    => 'Auditoría',
    'audit_report'			=> 'Registro de auditoría',
    'assets'				=> 'Activos',
    'avatar_delete'         => 'Eliminar Avatar',
    'avatar_upload'         => 'Subir Avatar',
    'back'      			=> 'Atrás',
    'bad_data'      		=> 'No se ha encontrado nada. ¿Tal vez datos erróneos?',
    'bulkaudit'             => 'Auditoría masiva',
    'bulkaudit_status'      => 'Estado de auditoría',
    'bulk_checkout'  		=> 'Procesar en Lote',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'por Estado',
    'cancel'  				=> 'Cancelar',
    'categories'			=> 'Categorías',
    'category'				=> 'Categoría',
    'change' 		        => 'Entrada/Salida',
    'changeemail'  			=> 'Cambiar dirección de email',
    'changepassword'  		=> 'Cambiar contraseña',
    'checkin'  				=> 'Entrada',
    'checkin_from'  		=> 'Devolución de',
    'checkout'  			=> 'Asignar',
    'checkouts_count'       => 'Dar de Baja',
    'checkins_count'        => 'Dar de Alta',
    'user_requests_count'   => 'Solicitudes',
    'city'  				=> 'Ciudad',
    'click_here'			=> 'Haz clic aquí',
    'clear_selection'		=> 'Borrar selección',
    'companies'			    => 'Compañías',
    'company'				=> 'Empresa',
    'component'			    => 'Componente',
    'components'			=> 'Componentes',
    'complete'				=> 'Completo',
    'consumable'			=> 'Consumible',
    'consumables'			=> 'Consumibles',
    'country'  				=> 'Pais',
    'create'				=> 'Crear Localización',
    'created'               => 'Artículo creado',
    'created_asset'			=> 'equipo creado',
    'created_at' 			=> 'Creado el',
    'record_created' 		=> 'Registro Creado',
    'updated_at' 			=> 'Actualizado en',
    'currency'  			=> '€', // this is deprecated
    'current'  				=> 'Actual',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Reporte de Equipos Personalizado',
    'dashboard'				=> 'Tablero',
    'days'      			=> 'días',
    'days_to_next_audit'    => 'Días a la próxima auditoría',
    'date'					=> 'Fecha Compra',
    'debug_warning'         => '¡Advertencia!',
    'debug_warning_text'    => 'Esta aplicación esta corriendo en modo producción con debugging activado. Esto puede exponer datos sensibles si su aplicación es accesible desde el exterior. Desactive el modo debug cambiando el valor <code>APP_DEBUG</code> en su archivo <code>.env</code> a <code>false</code>.',
    'delete'  				=> 'Borrar',
    'delete_confirm'  		=> '¿Estás seguro de eliminar :item?',
    'deleted'  				=> 'Borrado',
    'delete_seats'  		=> 'Asientos eliminados',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'Departamentos',
    'department'            => 'Departamento',
    'deployed'				=> 'Instalados - ',
    'depreciation'			=> 'Amortización',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Informe de amortización',
    'details'               => 'Detalles',
    'download'				=> 'Descargar',
    'download_all'		    => 'Descargar todo',
    'editprofile'  			=> 'Editar Perfil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Dominio de correo electrónico',
    'email_format'			=> 'Formato de correo electrónico',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Esto se utiliza para generar direcciones de correo electrónico cuando se importan',
    'error'				    => 'Error',
    'filastname_format'			=> 'Primera Inicial del Apellido (jsmith@ejemplo.com)',
    'firstname_lastname_format'	=> 'Primer Nombre y Apellido (jane.smith@ejemplo.com)',
    'firstname_lastname_underscore_format' => 'Primer Nombre y Apellido (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Apellido First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'first'					=> 'Primero',
    'firstnamelastname'     => 'Nombre Apellido (jane.smith@ejemplo.com)',
    'lastname_firstinitial' => 'Apellido Inicial (smith_j@ejemplo.com)',
    'firstinitial.lastname' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'firstnamelastinitial'  => 'Primer nombre y última inicial (janes@example.com)',
    'first_name'			=> 'Nombre',
    'first_name_format'		=> 'Primer Nombre (jane@ejemplo.com)',
    'files'                 => 'Archivos',
    'file_name'				=> 'Archivo',
    'file_type'             => 'Tipo de archivo',
    'file_uploads'			=> 'Carga de Archivos',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Generar',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'Este campo acepta el <a href="https://help.github.com/articles/github-flavored-markdown/">formateo flavored de GitHub</a>.',
    'groups'				=> 'Grupos',
    'gravatar_email'        => 'Gravatar Email',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Historial',
    'history_for'  			=> 'Historial de',
    'id'  					=> 'Id',
    'image'                 => 'Imagen',
    'image_delete'         	=> 'Borrar imagen',
    'image_upload'         	=> 'Enviar imagen',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Los tipos de archivo aceptados son jpg, webp, png, gif y svg. El tamaño máximo permitido es :size.',
    'import'         	    => 'Importar',
    'importing'         	=> 'Importando',
    'importing_help'        => 'Puedes importar activos, accesorios, licencias, componentes, insumos y usuarios vía archivos CSV.<br> <br> El CSV debe estar delimitado por comas y formateado con encabezados que coincidan con aquellos definidos en los <a href="https://snipe-it.readme.io/docs/importing" target="_new"> CSVs de muestra en la documentación</a>.',
    'import-history'        => 'Historial de Importación',
    'asset_maintenance'        => 'Mantenimiento de Equipo',
    'asset_maintenance_report' => 'Reporte de Mantenimiento de Equipo',
    'asset_maintenances'       => 'Mantenimientos de Equipo',
    'item'  				=> 'Item',
    'item_name'             => 'Nombre del ítem',
    'insufficient_permissions' => '¡Permisos insuficientes!',
    'kits'       			=> 'Equipamiento predefinido',
    'language'				=> 'Lenguaje',
    'last'					=> 'Último',
    'last_login'            => 'Último acceso',
    'last_name'             => 'Apellidos',
    'license'				=> 'Licencia',
    'license_report'        => 'Reporte de Licencias',
    'licenses_available'	=> 'licencias libres',
    'licenses'				=> 'Licencias',
    'list_all'				=> 'Listar Todo',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'El valor de este campo no será guardado en una instalación de demostración.',
    'feature_disabled'      => 'Esta característica se ha desactivado para la versión de demostración.',
    'location'              => 'Localización',
    'locations'				=> 'Localizaciones',
    'logo_size'				=> 'Los logotipos cuadrados se ven mejor con Logo + Texto. El tamaño máximo del logo es 50px de altura x 500px de ancho.  ',
    'logout'				=> 'Desconexión',
    'lookup_by_tag'     => 'Buscar por etiqueta de activo',
    'maintenances'          => 'Mantenimientos',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Fabricante',
    'manufacturers'			=> 'Fabricantes',
    'markdown'				=> 'Este campo permite <a href="https://help.github.com/articles/github-flavored-markdown/">Github con sabor a markdown</a>.',
    'min_amt'				=> 'Cantidad mínima',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Modelo No.',
    'months'				=> 'Meses',
    'moreinfo'				=> 'Más Info',
    'name'					=> 'Nombre Localización',
    'new_password'          => 'New Password',
    'next'					=> 'Siguiente',
    'next_audit_date'		=> 'Próxima fecha de auditoría',
    'last_audit'		    => 'Última auditoría',
    'new'					=> 'nuevo!',
    'no_depreciation'		=> 'No Amortizar',
    'no_results'			=> 'Sin Resultados.',
    'no'  					=> 'No',
    'notes'  				=> 'Notas',
    'order_number'          => 'Nùmero de orden',
    'page_menu'				=> 'Mostrando elementos de _MENU_',
    'pagination_info'		=> 'Mostrando _START_ de _END_ de elementos _TOTAL_',
    'pending'				=> 'Equipo Pendiente',
    'people'				=> 'Usuarios',
    'per_page'				=> 'Resultados Por Pag',
    'previous'				=> 'Previo',
    'processing'			=> 'Procesando',
    'profile'				=> 'Perfil',
    'purchase_cost'                              => 'Precio Compra',
    'purchase_date'         => 'Fecha de compra',
    'qty'		            => 'Cant',
    'quantity'		        => 'Cantidad',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Disponibles',
    'recent_activity'		=> 'Actividad Reciente',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Eliminar Asociación de compañía',
    'reports'				=> 'Informes',
    'restored'				=> 'restaurado',
    'restore'				=> 'Restaurar',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Solicitado',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Solicitud Cancelada',
    'save'  				=> 'Guardar',
    'select'				=> 'Seleccionar',
    'select_all'            => 'Select All',
    'search'				=> 'Buscar',
    'select_category'       => 'Seleccione una categoría',
    'select_department'     => 'Seleccione un departamento',
    'select_depreciation'	=> 'Seleccionar un tipo de Amortización',
    'select_location'		=> 'Seleccionar una Ubicación',
    'select_manufacturer'	=> 'Seleccionar un Fabricante',
    'select_model'			=> 'Seleccionar un Modelo',
    'select_supplier'		=> 'Seleccionar un Proveedor',
    'select_user'			=> 'Seleccionar un usuario',
    'select_date'			=> 'Seleccione Fecha (AAAA-MM-DD)',
    'select_statuslabel'	=> 'Seleccionar Estado',
    'select_company'    	=> 'Seleccionar empresa',
    'select_asset'    		=> 'Seleccionar activos',
    'settings'				=> 'Opciones',
    'show_deleted'  		=> 'Mostrar Eliminado',
    'show_current'  		=> 'Mostrar actual',
    'sign_in'				=> 'Entrar',
    'signature'             => 'Firma',
    'skin'       			=> 'Tema',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => '¡Parece que tu integración de Slack con Snipe-IT está funcionando!',
    'some_features_disabled' => 'MODO DE DEMOSTRACIÓN: Algunas funciones estan desactivadas para esta instalación.',
    'site_name'				=> 'Sitio',
    'state'  				=> 'Provincia',
    'status_labels'			=> 'Etiquetas Estados',
    'status'    			=> 'Estados',
    'supplier'              => 'Proveedor',
    'suppliers'  			=> 'Proveedores',
    'sure_to_delete'    => '¿Está seguro que desea eliminar',
    'submit'				=> 'Enviar',
    'target'                => 'Objetivo',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Hora y fecha',
    'total_assets'			=> 'Equipos',
    'total_licenses'		=> 'licencias totales',
    'total_accessories'		=> 'total de accesorios',
    'total_consumables'		=> 'total de consumibles',
    'type'  				=> 'Tipo',
    'undeployable'			=> 'No Instalable',
    'unknown_admin'			=> 'Admin Desconocido',
    'username_format'		=> 'Formato del nombre de usuario',
    'update'                => 'Actualizar',
    'upload_filetypes_help'      => 'Los tipos de archivo permitidos son png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf y rar. El tamaño máximo permitido es :size.',
    'uploaded'              => 'Subido',
    'user'					=> 'Usuario',
    'accepted'			    => 'aceptado',
    'declined'			    => 'declinado',
    'unaccepted_asset_report' => 'Activos no aceptados',
    'users'                 => 'Usuarios',
    'viewall'				=> 'Ver todos',
    'viewassets'  			=> 'Ver Equipos Asignados',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Sitio web',
    'welcome'				=> 'Bienvenido, :name',
    'years'					=> 'años',
    'yes' 					=> 'Si',
    'zip'  					=> 'Códio Postal',
    'noimage'				=> 'Imagen no subida o imagen no encontrada.',
    'token_expired'         => 'Su sesión ha expirado, Intente otra ves.',
    'login_enabled'         => 'Inicio de sesión habilitado',
    'audit_due'             => 'Auditoría pendiente',
    'audit_overdue'         => 'Auditoría retrasada',
    'accept'                => 'Aceptar :asset',
    'i_accept'              => 'Acepto',
    'i_decline'             => 'Rechazo',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Firma abajo para indicar que estás de acuerdo con los términos de servicio:',
    'clear_signature'       => 'Borrar firma',
    'show_help'             => 'Mostrar ayuda',
    'hide_help'             => 'Ocultar ayuda',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
